/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  EdgeDisplayOptions							//
//  ------------------							//
//									//
//  Specific options in the 'Display' dialogue for the EDGE engine.	//
//									//
//////////////////////////////////////////////////////////////////////////

#include <klocale.h>

#include <qlayout.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qlabel.h>

#include "edgedisplayoptions.h"
#include "edgedisplayoptions.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

EdgeDisplayOptions::EdgeDisplayOptions(QWidget *parent,const QSize &size,DisplayOptions::Option opt)
	: DisplayOptions(parent,size,opt)
{
	QButtonGroup *bg = new QButtonGroup(1,Qt::Vertical,sizegroup);
	bg->setFrameStyle(QFrame::NoFrame);		// fullscreen/window radio buttons

	fullscreen = new QRadioButton(i18n("Full screen"),bg);
	windowed = new QRadioButton(i18n("In window"),bg);

	QGridLayout *l2 = static_cast<QGridLayout *>(sizegroup->layout());
							// layout of parent group
	l2->addMultiCellWidget(bg,3,3,2,5);
	l2->setRowSpacing(3,0); l2->setRowStretch(3,0); 
	l2->setRowSpacing(4,KDialog::spacingHint()); l2->setRowStretch(4,9); 

	QLabel *lab = new QLabel(i18n("Show:"),sizegroup);
	l2->addWidget(lab,3,1,Qt::AlignRight);		// radio buttons text label

	windowed->setChecked(opt & DisplayOptions::Windowed);
	fullscreen->setChecked(!windowed->isChecked());

	expcombo->setEnabled(false);			// these not supported in EDGE
	expcombo->setCurrentItem(0);
	noaccel->setEnabled(false); noaccel->setChecked(false);
	nojoy->setEnabled(false); nojoy->setChecked(false);
	nomouse->setEnabled(false); nomouse->setChecked(false);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Returned results							//
//									//
//////////////////////////////////////////////////////////////////////////

DisplayOptions::Option EdgeDisplayOptions::options() const
{
	int opt = DisplayOptions::options();
	if (windowed->isChecked()) opt |= DisplayOptions::Windowed;
	return ((DisplayOptions::Option) opt);
}
