/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  JdoomGame								//
//  ---------								//
//									//
//  Specific game engine implementation for Jdoom (aka Doomsday).	//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <klocale.h>

#include <qwidget.h>
#include <qdir.h>
#include <qfile.h>

#include "gamemanager.h"
#include "genericgame.h"

#include "jdoomgame.h"
#include "jdoomgame.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Engine information							//
//									//
//////////////////////////////////////////////////////////////////////////

class JdoomGameInfo
{
public:
	static const GameManager::gameInfo myinfo;

protected:
	static GenericGame *create(QWidget *parent);

private:
	static JdoomGameInfo initobj;
	JdoomGameInfo();
};


const GameManager::gameInfo JdoomGameInfo::myinfo =
{
	"jdoom",					// key
	"Doomsday",					// name
	"http://www.doomsdayhq.com",			// url
	i18n("This engine cannot play back demo files in the old LMP format. See \
<a href=\"http://archive.doomsdayhq.com/faq.php?topic=6#question60\">http://archive.doomsdayhq.com/faq.php?topic=6#question60</a> \
for details."),						// notes
	"jdoom",					// execname
	QString::null,					// execpaths
	QString::null,					// datapaths
	&JdoomGameInfo::create				// createfunc
};


JdoomGameInfo JdoomGameInfo::initobj;


JdoomGameInfo::JdoomGameInfo()
{
	GameManager::self()->add(&JdoomGameInfo::myinfo);
}


GenericGame *JdoomGameInfo::create(QWidget *parent)
{
	kdDebug(0) << k_funcinfo << endl;

	GenericGame *g = new JdoomGame(parent);
	return (g);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

JdoomGame::JdoomGame(QWidget *parent)
	: GenericGame(parent)
{
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Saved games and information						//
//									//
//////////////////////////////////////////////////////////////////////////

QStringList JdoomGame::findSavedGames()
{
	kdDebug(0) << k_funcinfo << endl;
	QStringList l;

	QDir d = QDir::home();
	if (!d.cd(".doomsday/jdoom/savegame"))
	{
		kdDebug(0) << k_funcinfo << "no saved game directory" << endl;
		return (l);
	}

	d.setFilter(QDir::Dirs+QDir::Readable);
	QStringList l1 = d.entryList("*");		// directory for each base WAD

	for (QStringList::const_iterator it = l1.begin(); it!=l1.end(); ++it)
	{
		for (int i = 0; i<=7; ++i)		// save slots within each one
		{
			QFile f(d.absFilePath(QString("%2/DoomSav%1.dsg").arg(i).arg(*it)));
			if (!f.exists()) continue;

			QString desc = QString("%1: (%2)").arg(i).arg(*it);
			l.append(desc);
		}
	}

	kdDebug(0) << k_funcinfo << "returning " << l.join(",") << endl;
	return (l);
}


const GameManager::gameInfo *JdoomGame::gameInfo()
{
	return (&JdoomGameInfo::myinfo);
}


QString JdoomGame::demoFormat() const			// Doomsday can't play LMP demos
{
	return (QString::null);
}
