/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  PWadList								//
//  --------								//
//									//
//  Scrolling/droppable list and associated buttons for the		//
//  "Additional WADs" section of the main window.			//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <klocale.h>
#include <kdialog.h>
#include <kfiledialog.h>
#include <kurldrag.h>
#include <kurl.h>
#include <kiconloader.h>

#include <qwidget.h>
#include <qlayout.h>
#include <qgroupbox.h>
#include <qpushbutton.h>

#include "gamemanager.h"
#include "droppablelistbox.h"
#include "infodisplay.h"

#include "pwadlist.h"
#include "pwadlist.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

PWadList::PWadList(QWidget *parent)
	: QWidget(parent)
{
	QGridLayout *l2 = new QGridLayout(this,6,2,0,KDialog::spacingHint());
							// our internal layout
	pwads = new DroppableListBox(this);		// main list box
	pwads->setSelectionMode(QListBox::Extended);
	pwads->setVScrollBarMode(QScrollView::AlwaysOn);
	pwads->setMinimumHeight(80);
	connect(pwads,SIGNAL(selectionChanged()),this,SLOT(slotChangedPWad()));
	connect(pwads,SIGNAL(dropped(const KURL &)),this,SLOT(slotDropped(const KURL &)));
	l2->addMultiCellWidget(pwads,0,5,0,0);

	pwadadd = new QPushButton(KGlobal::iconLoader()->loadIcon("add",KIcon::Small),i18n("Add..."),this);
	connect(pwadadd,SIGNAL(clicked()),this,SLOT(slotWadAdd()));
	l2->addWidget(pwadadd,0,1);			// "Add" button

	pwadremove = new QPushButton(KGlobal::iconLoader()->loadIcon("delete",KIcon::Small),i18n("Remove"),this);
	connect(pwadremove,SIGNAL(clicked()),this,SLOT(slotWadRemove()));
	l2->addWidget(pwadremove,1,1);			// "Remove" button

	pwadmoveup = new QPushButton(KGlobal::iconLoader()->loadIcon("up",KIcon::Small),i18n("Move Up"),this);
	connect(pwadmoveup,SIGNAL(clicked()),this,SLOT(slotWadMoveUp()));
	l2->addWidget(pwadmoveup,2,1);			// "Move Up" button

	pwadmovedown = new QPushButton(KGlobal::iconLoader()->loadIcon("down",KIcon::Small),i18n("Move Down"),this);
	connect(pwadmovedown,SIGNAL(clicked()),this,SLOT(slotWadMoveDown()));
	l2->addWidget(pwadmovedown,3,1);		// "Move Down" button

	pwadinfo = new QPushButton(KGlobal::iconLoader()->loadIcon("info",KIcon::Small),i18n("WAD Info..."),this);
	connect(pwadinfo,SIGNAL(clicked()),this,SLOT(slotWadInfo()));
	l2->addWidget(pwadinfo,4,1);			// "Info" button

	l2->setRowStretch(5,9);
	l2->setColStretch(0,9);

	adjustSize();

	slotChangedPWad();
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Action slots							//
//									//
//////////////////////////////////////////////////////////////////////////

void PWadList::slotWadAdd()
{
	KURL w = KFileDialog::getOpenURL(":pwads",
					 GameManager::wadFilterText,this,
					 GameManager::wadCaptionText);
	if (w.isValid()) slotDropped(w.pathOrURL());
	emit listChanged();
}


void PWadList::slotWadRemove()
{
	bool changed = false;
	for (int i = pwads->count()-1; i>=0; --i)
	{
		if (pwads->item(i)->isSelected())
		{
			pwads->removeItem(i);
			changed = true;
		}
	}

	if (changed) emit listChanged();
}


void PWadList::slotWadInfo()
{
	QString wad;

	// Need this loop, because the list box is in Extended selection mode
	// and QListBox::selectedItem() only works in Single.
	for (unsigned int i = 0; i<pwads->count(); ++i)
	{
		if (pwads->item(i)->isSelected())
		{
			wad = pwads->item(i)->text();
			break;
		}
	}

	if (wad.isNull()) return;

	kdDebug(0) << k_funcinfo << "for " << wad << endl;
	InfoDisplay *inf = new InfoDisplay(wad);
	inf->showInfo();
}


static bool moveUpOrDown(QListBox *list,int dir)
{
	bool changed = false;
	for (unsigned int i = 0; i<list->count(); ++i)
	{
		if (list->item(i)->isSelected())
		{
			const QString temp = list->text(i);
			list->removeItem(i);
			list->insertItem(temp,i+dir);
			list->setSelected(i+dir,true);
			changed = true;
			break;
		}
	}

	return (changed);
}


void PWadList::slotWadMoveUp()
{
	if (moveUpOrDown(pwads,-1)) emit listChanged();
}


void PWadList::slotWadMoveDown()
{
	if (moveUpOrDown(pwads,+1)) emit listChanged();
}


void PWadList::slotChangedPWad()
{
	int selcount = 0;				// count of items selected
	int selitem = -1;				// item that is selected
	for (unsigned int i = 0; i<pwads->count(); ++i)
	{
		if (!pwads->item(i)->isSelected()) continue;
		selitem = i+1;				// note the selected item
		++selcount;				// count total selected
	}

	pwadremove->setEnabled(selcount>0);		// enable action buttons
	pwadmoveup->setEnabled(selcount==1 && selitem>1);
	pwadmovedown->setEnabled(selcount==1 && selitem<pwads->count());
	pwadinfo->setEnabled(selcount==1);
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Drag and drop							//
//									//
//////////////////////////////////////////////////////////////////////////

void PWadList::slotDropped(const KURL &url)
{
	kdDebug(0) << k_funcinfo << "url='" << url.prettyURL() << "'\n";

	pwads->clearSelection();
	pwads->insertItem(url.url());			// append to list at end
	pwads->setSelected(pwads->count()-1,true);
	emit listChanged();
}
