/////////////////////////////////////////////////// -*- mode:c++; -*- ////
//  Copyright (C) 2008 by Jonathan Marten				//
//  jjm@keelhaul.me.uk							//
//									//
//  This program is free software; you can redistribute it and/or	//
//  modify it under the terms of the GNU General Public License as	//
//  published by the Free Software Foundation; either version 2 of	//
//  the License, or (at your option) any later version.			//
//									//
//  This program is distributed in the hope that it will be useful,	//
//  but WITHOUT ANY WARRANTY; without even the implied warranty of	//
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	//
//  GNU General Public License for more details.			//
//									//
//  You should have received a copy of the GNU General Public License	//
//  along with this program; if not, write to the			//
//  Free Software Foundation, Inc.,					//
//  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.		//
//									//
//////////////////////////////////////////////////////////////////////////


//////////////////////////////////////////////////////////////////////////
//									//
//  This file is part of Kadoom, a KDE desktop front end to various	//
//  Doom game engines.  See http://www.keelhaul.me.uk/linux/kadoom	//
//  for the latest version and further information.			//
//									//
//									//
//  SoundOptions							//
//  ------------							//
//									//
//  The generic 'Sound' options dialogue, with common and useful	//
//  options.  Some game engines may add options to or remove		//
//  them from this dialogue.						//
//									//
//////////////////////////////////////////////////////////////////////////

#include <kdebug.h>
#include <kdialog.h>
#include <klocale.h>

#include <qcheckbox.h>
#include <qbuttongroup.h>

#include "soundoptions.h"
#include "soundoptions.moc"

//////////////////////////////////////////////////////////////////////////
//									//
//  Text strings							//
//									//
//////////////////////////////////////////////////////////////////////////

static const QString capt = i18n("Sound Options");

//////////////////////////////////////////////////////////////////////////
//									//
//  Constructor/destructor						//
//									//
//////////////////////////////////////////////////////////////////////////

SoundOptions::SoundOptions(QWidget *parent,SoundOptions::Option opt)
	: KDialogBase(parent)
{
	setCaption(capt);
	showButtonApply(false);				// uses "OK" and "Cancel" only

	buttongroup = new QButtonGroup(1,Qt::Horizontal,capt,this);
	setMainWidget(buttongroup);			// main (and only) group box

	nosfx = new QCheckBox(i18n("Sound effects"),buttongroup);
	nomusic = new QCheckBox(i18n("Background music"),buttongroup);

	buttongroup->adjustSize();

	nosfx->setChecked(!(opt & SoundOptions::NoSfx));
	nomusic->setChecked(!(opt & SoundOptions::NoMusic));
}

//////////////////////////////////////////////////////////////////////////
//									//
//  Returned results							//
//									//
//////////////////////////////////////////////////////////////////////////

SoundOptions::Option SoundOptions::options(void) const
{
	int opt = SoundOptions::Null;
	if (!nosfx->isChecked()) opt |= SoundOptions::NoSfx;
	if (!nomusic->isChecked()) opt |= SoundOptions::NoMusic;
	return ((SoundOptions::Option) opt);
}
